function idn_con

% IDN_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.11 $ $Date: 1998/12/31 21:14:28 $

helpwin('idn_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  idn_con
%
%Double click on any function for more information
%
%  System Identification Toolbox.
%  Version 4.0.5 (R11) 10-Apr-1998
% 
%  New Features.
%    Readme      - Important release information about the System ID Toolbox 
%                  (double click on Readme, or type "whatsnew directoryname", 
%                   i.e. "whatsnew ident" to display this file).
%  Demos
%    iddemo     - Demonstrates the use of the toolbox.
% 
%  Graphical User Interface
%    ident      - A comprehensive estimation and analysis environment.
%    midprefs   - Specify a directory for start-up information.
% 
%  Simulation and prediction.
%    idsim      - Simulate a given system.
%    pe         - Prediction errors.
%    poly2th    - Construct a "theta-matrix" from given polynomials.
%    predict    - M-step ahead prediction.
% 
%  Data manipulation.
%    dtrend     - Remove trends from data sets.1
%    idfilt     - Filter data through Butterworth filters.
%    idinput    - Generates input signals for identification.
%    idresamp   - Resamples data by decimation and interpolation.
% 
%  Nonparametric estimation.
%    covf       - Covariance function estimate for a data matrix.
%    cra        - Correlation analysis.
%    etfe       - Empirical Transfer Function Estimate and Periodogram.
%    spa        - Spectral analysis.
% 
%  Parameter estimation.
%    ar         - AR-models of signals using various approaches.
%    armax      - Prediction error estimate of an ARMAX model.
%    arx        - LS-estimate of ARX-models.
%    bj         - Prediction error estimate of a Box-Jenkins model.
%    canstart   - Multivariable theta-model with initial parameter estimates.
%    ivar       - IV-estimates for the AR-part of a scalar time series.
%    iv4        - Approximately optimal IV-estimates for ARX-models.
%    n4sid      - State-space model estimation using a sub-space method.
%    oe         - Prediction error estimate of an output-error model.
%    pem        - Prediction error estimate of a general linear model.
% 
%  Model structure creation.
%    arx2th     - THETA-format for an ARX model.
%    canform    - Canonical form model structures.
%    mf2th      - Package user defined model structures into the THETA model format.
%    modstruc   - Model structures to be used in MS2TH.
%    ms2th      - Package standard state-space parameterizations into the THETA format.
%    poly2th    - "Theta-matrix" from given polynomials.
% 
%  Manipulating model structures.
%    fixpar     - Fix parameters in state-space and ARX model structures.
%    sett       - Set the sampling interval in TH-structures.
%    thinit     - (Random) initial values for the parameters.
%    unfixpar   - Unfix parameters in state-space and ARX model structures.
% 
%  Model conversions.
%    idmodred   - Reduce a model to lower order.
%    th2arx     - Convert a THETA-format model to an ARX-model.
%    th2ff      - Model's frequency function, along with its standard deviation.
%    th2par     - Theta-format to parameters and covariance matrix.
%    th2poly    - Polynomials associated with a given model.
%    th2ss      - THETA model conversion to state-space.
%    th2tf      - THETA model conversion to transfer function.
%    th2zp      - Zeros, poles, static gains and their standard deviations.
%    thc2thd    - Continuous time model to discrete time.
%    thd2thc    - Model to continuous-time form.
% 
%  Model presentation.
%    bodeplot   - Bode diagram of a transfer function or spectrum.
%    ffplot     - Frequency functions.
%    idplot     - Input - output data.
%    nyqplot    - Nyquist diagram of a transfer function.
%    present    - Parametric model on the screen.
%    zpplot     - Zeros and poles.
% 
%  Information extraction.
%    getmfth    - Get the name of the .m-file that defines the model structure.
%    getncap    - Get the number of data points and the number of parameters.
%    getff      - Select the frequency function (for own plotting).
%    gett       - Get the sampling interval for a model.
%    getzp      - Extract the zeros and the poles from the ZEPO-format created by TH2ZP.
%    th2par     - Theta-format to parameters and covariance matrix.
% 
%  Model validation.
%    compare    - Compare the simulated/predicted output with the measured output.
%    idsim      - Simulate a given system.
%    pe         - Prediction errors.
%    predict    - M-step ahead prediction.
%    resid      - Compute and test the residuals associated with a model.
% 
%  Assessing model uncertainty.
%    idsimsd    - Illustrate the uncertainty in simulated model responses.
%    th2ff      - Model's frequency function and standard deviation.
%    th2zp      - Zeros, poles, static gains and their standard deviations.
% 
%  Model structure selection.
%    arxstruc   - Loss functions for families of ARX-models.
%    ivstruc    - Output error fit for families of single-output.
%    selstruc   - Select model structures according to various criteria.
%    struc      - Typical structure matrices for ARXSTRUC and IVSTRUC.
%

function Readme
%MATLAB Tour Partial Function Help:  idn_con
%
%  Release Notes System Identification Toolbox 4.0.3
% 
%  System Identification version 4.0.3 is a MATLAB 5 compliant version. The
%  functionality is similar to the System ID Toolbox version 4.0
%  running under MATLAB 4.2c.
% 
%  Compared to version 3 it has the following enhancements:
% 
%  The main addition from version 3.0a is that a graphical user
%  interface, ident, is available. Most of the toolbox's functions
%  can be accessed through this interface. To start it, type
% 
%    ident
% 
%  at the MATLAB command line. There is an interactive demo available
%  (under the Help menu) that illustrates the use of the interface.
% 
%  Version 4.0 also includes some new functions:
% 
%    n4sid:     A subspace method to estimate state-space models
%    idinput:   Generates input signals for identification.
%    idresamp:  Resamples data by decimation and interpolation.
%    idmodred:  Model reduction for models given in the theta-format
%    ss2th:     Transformation from an arbitrary state-space model
%           to a parmetrized model in observer canonical form
% 
%  Some functions have added features:
% 
%    idsim:     Now allows for the computation of confidence intervals
%           around the simulated output.
%    armax, bj, oe, and pem:  These iterative estimation procedures
%           no longer automatically give information to the
%           MATLAB command window. To obtain that, a last argument
%           with the value 'trace' must be supplied.
% 
%  To get more information about the routines use HELP.
% 
%  Complement to the manual: The input argument TOL (described under
%          AUXVAR in the manual) has a new interpretation. It
%          corresponds to the expected relative improvement of
%          the criterion of fit, measured in percent. See HELP AUXVAR.
% 
%  List of known bugs or bad behavior.
%  1) When new lines are added to plots, the plot figure will pop to the
%     front.  This is necessary in MATLAB 4.x which requires that lines
%     and axes be created in the CurrentFigure only.
%  2) It is good practice to press the Return key after having filled out
%     any white edit field in the graphical interface. This will execute
%     the callback to the edit control. Otherwise you may have to click
%     twice on any action pushbutton to make it react. This is because
%     the first click will execute the callback to the edit control.
%     This "feature" is expected by people with click-to-focus pointer
%     policy, but is considered "bad behavior" by people who use
%     a point-to-focus pointer policy.
%  3) If a command window error occurs when executing a callback, the
%     cursor may stay in its 'watch' mode. Then just click anywhere in
%     the main ident window to restore it to 'arrow'.

function iddemo
%MATLAB Tour Partial Function Help:  idn_con
%
%    The SYSTEM IDENTIFICATION TOOLBOX is an analysis module
%    that contains tools for building mathematical models of
%    dynamical systems, based upon observed input-output data.
%    The toolbox contains both PARAMETRIC and NON-PARAMETRIC
%    MODELING methods.
% 
%    Identification Toolbox demonstrations:
% 
%    1) The Graphical User Interface (ident): A guided Tour.
%    2) Build simple models from real laboratory process data.
%    3) Compare different identification methods.
%    4) Model structure determination case study.
%    5) Spectrum estimation (Marple's test case).
%    6) Adaptive/Recursive algorithms.
%    7) Segmentation of data and models.
%    8) State-space and multi-output models.
%    9) Case studies
% 
%    0) Quit

function ident
%MATLAB Tour Partial Function Help:  idn_con
%
%  System Identification Toolbox.
%  Version 4.0.5 (R11) 10-Apr-1998
% 
%  New Features.
%    Readme      - Important release information about the System ID Toolbox 
%                  (double click on Readme, or type "whatsnew directoryname", 
%                   i.e. "whatsnew ident" to display this file).
%  Demos
%    iddemo     - Demonstrates the use of the toolbox.
% 
%  Graphical User Interface
%    ident      - A comprehensive estimation and analysis environment.
%    midprefs   - Specify a directory for start-up information.
% 
%  Simulation and prediction.
%    idsim      - Simulate a given system.
%    pe         - Prediction errors.
%    poly2th    - Construct a "theta-matrix" from given polynomials.
%    predict    - M-step ahead prediction.
% 
%  Data manipulation.
%    dtrend     - Remove trends from data sets.1
%    idfilt     - Filter data through Butterworth filters.
%    idinput    - Generates input signals for identification.
%    idresamp   - Resamples data by decimation and interpolation.
% 
%  Nonparametric estimation.
%    covf       - Covariance function estimate for a data matrix.
%    cra        - Correlation analysis.
%    etfe       - Empirical Transfer Function Estimate and Periodogram.
%    spa        - Spectral analysis.
% 
%  Parameter estimation.
%    ar         - AR-models of signals using various approaches.
%    armax      - Prediction error estimate of an ARMAX model.
%    arx        - LS-estimate of ARX-models.
%    bj         - Prediction error estimate of a Box-Jenkins model.
%    canstart   - Multivariable theta-model with initial parameter estimates.
%    ivar       - IV-estimates for the AR-part of a scalar time series.
%    iv4        - Approximately optimal IV-estimates for ARX-models.
%    n4sid      - State-space model estimation using a sub-space method.
%    oe         - Prediction error estimate of an output-error model.
%    pem        - Prediction error estimate of a general linear model.
% 
%  Model structure creation.
%    arx2th     - THETA-format for an ARX model.
%    canform    - Canonical form model structures.
%    mf2th      - Package user defined model structures into the THETA model format.
%    modstruc   - Model structures to be used in MS2TH.
%    ms2th      - Package standard state-space parameterizations into the THETA format.
%    poly2th    - "Theta-matrix" from given polynomials.
% 
%  Manipulating model structures.
%    fixpar     - Fix parameters in state-space and ARX model structures.
%    sett       - Set the sampling interval in TH-structures.
%    thinit     - (Random) initial values for the parameters.
%    unfixpar   - Unfix parameters in state-space and ARX model structures.
% 
%  Model conversions.
%    idmodred   - Reduce a model to lower order.
%    th2arx     - Convert a THETA-format model to an ARX-model.
%    th2ff      - Model's frequency function, along with its standard deviation.
%    th2par     - Theta-format to parameters and covariance matrix.
%    th2poly    - Polynomials associated with a given model.
%    th2ss      - THETA model conversion to state-space.
%    th2tf      - THETA model conversion to transfer function.
%    th2zp      - Zeros, poles, static gains and their standard deviations.
%    thc2thd    - Continuous time model to discrete time.
%    thd2thc    - Model to continuous-time form.
% 
%  Model presentation.
%    bodeplot   - Bode diagram of a transfer function or spectrum.
%    ffplot     - Frequency functions.
%    idplot     - Input - output data.
%    nyqplot    - Nyquist diagram of a transfer function.
%    present    - Parametric model on the screen.
%    zpplot     - Zeros and poles.
% 
%  Information extraction.
%    getmfth    - Get the name of the .m-file that defines the model structure.
%    getncap    - Get the number of data points and the number of parameters.
%    getff      - Select the frequency function (for own plotting).
%    gett       - Get the sampling interval for a model.
%    getzp      - Extract the zeros and the poles from the ZEPO-format created by TH2ZP.
%    th2par     - Theta-format to parameters and covariance matrix.
% 
%  Model validation.
%    compare    - Compare the simulated/predicted output with the measured output.
%    idsim      - Simulate a given system.
%    pe         - Prediction errors.
%    predict    - M-step ahead prediction.
%    resid      - Compute and test the residuals associated with a model.
% 
%  Assessing model uncertainty.
%    idsimsd    - Illustrate the uncertainty in simulated model responses.
%    th2ff      - Model's frequency function and standard deviation.
%    th2zp      - Zeros, poles, static gains and their standard deviations.
% 
%  Model structure selection.
%    arxstruc   - Loss functions for families of ARX-models.
%    ivstruc    - Output error fit for families of single-output.
%    selstruc   - Select model structures according to various criteria.
%    struc      - Typical structure matrices for ARXSTRUC and IVSTRUC.
%
%
%ident is both a directory and a function.
%
% IDENT  Starts the Graphical User Interface for the System Identification Toolbox.
% 
%    ident   or  ident(SESSION,PATH)
%    
%    IDENT by itself opens the main interface window.
%    SESSION is a SITB session file (typically with extension .sid)
%    PATH is the search path for this file. (Not necessary if on the
%    MATHLABPATH.) When SESSION is specified, the interface opens
%    with this session.
%    
%    When the interface is active, ident(SESSION,PATH) will open the
%    session SESSION.

function midprefs
%MATLAB Tour Partial Function Help:  idn_con
%
% MIDPREFS Choose directory for idprefs.mat, the ident start-up info file.
% 
%    midprefs  or midprefs(PATH)
% 
%    The Graphical User Interface to the System Identification toolbox
%    uses a file idprefs.mat to store start-up information, like preferred
%    window sizes and locations and most recently used session files.
%    By default this file is stored in the same directory as startup.m,
%    if this .m file exists.
% 
%    To select another directory, use the function MIDPREFS. Simply type
%    the function name and follow the instructions, or give the directory
%    as an argument. Include all directory delimiters.
% 
%    Example (PC): midprefs('c:\matlab\toolbox\local\')

function idsim
%MATLAB Tour Partial Function Help:  idn_con
%
% IDSIM  Simulates a given dynamic system.
%    Y = IDSIM(UE,TH)
% 
%    TH: contains the parameters of the model in the format described by 
%    (

function pe
%MATLAB Tour Partial Function Help:  idn_con
%
% PE   Computes prediction errors.
%    E = PE(Z,TH)
% 
%    E : The prediction errors
%    Z : The output-input data Z=[y u]
%    TH: The model. Format as in HELP THETA
% 
%    A more complete set of information associated with the model TH and the
%    data Z is obtained by
% 
%    [E,V,W,A,B,C,D,F] = PE(Z,TH)
% 
%    Here A,B,C,D,and F are the polynomials associated with TH and
%    W = B/F u and V = A[y - W].

function poly2th
%MATLAB Tour Partial Function Help:  idn_con
%
% POLY2TH Constructs a "theta-matrix" from given polynomials.
%    TH = POLY2TH(A,B,C,D,F,LAM,T)
% 
%    TH: returned as a matrix of the standard format, describing the model
%    A(q) y(t) = [B(q)/F(q)] u(t-nk) + [C(q)/D(q)] e(t)
%    The exact format is given as in (

function predict
%MATLAB Tour Partial Function Help:  idn_con
%
% PREDICT Computes the m-step ahead prediction.
%    YP = PREDICT(Z,TH,M)
%    
%    Z : The output - input data for which the prediction is computed.
%        Z = [Y U], where Y and U are column vectors (one column for each 
%        output and input)
%    TH: The model in the THETA format (

function dtrend
%MATLAB Tour Partial Function Help:  idn_con
%
% DTREND Removes trends from data sets.
%    ZD = DTREND(Z)    or   ZD = DTREND(Z,O,BREAKPOINTS)
% 
%    Z is the data set to be detrended, organized with the data records as
%    column vectors. ZD is returned as the detrended data.
% 
%    If O = 0 (the default case) the sample means are removed from each of
%    the columns.
% 
%    If O = 1, linear trends are removed. A continuous, piecewise linear
%    trend is adjusted to each of the data records, and then removed. The
%    interior breakpoints for the linear trend segments are contained in
%    the row vector BREAKPOINTS. The default value is that there are no
%    interior breakpoints, so that one single straight line is removed from
%    each of the data records.
% 
%    This function is obsolete.  Please use DETREND instead.
% 
%    

function idfilt
%MATLAB Tour Partial Function Help:  idn_con
%
% IDFILT Filters data.
%    ZF = IDFILT(Z,N,Wn)
% 
%    Z  : The output-input data matrix Z = [Y U]. Multi-variable
%         data are allowed
%    ZF : The filtered data. The columns of ZF correspond to those of Z.
%    N  : The order of the filter to be used.
%         N = a positive integer: gives an acausal, zero-phase filter of
%             order 2N, determined from a Butterworth filter.
%         N = a negative integer: gives a causal Butterworth filter of
%             order abs(N).
%    Wn : The cut-off frequency(ies) in fractions of the Nyquist frequency.
%         If Wn is a scalar a Low-Pass filter will be used.
%         If Wn = [Wl Wh] a Band-Pass filter with pass-band  Wn will be used
% 
%    With ZF = IDFILT(Z,N,Wn,'high') or ZF = IDFILT(Z,N,[Wl Wh],'stop')
%    High-Pass and Band-Stop filters will be used instead.
% 
%    With [ZF,THFILT] = IDFILT(Z,N,Wn), also the filter will be returned
%    in the THETA-format as THFILT. (

function idinput
%MATLAB Tour Partial Function Help:  idn_con
%
% IDINPUT Generates input signals for identification.
%    U = IDINPUT(N,TYPE,BAND,LEVELS)
% 
%    U: The generated input signal, a column vector.
%    N: The length of the input.
%    TYPE: One of the following:
%          'RGS': Generates a Random, Gaussian Signal.
%          'RBS': Generates a Random, Binary Signal.
%          'PRBS': Generates a Pseudo-random, Binary Signal.
%          'SINE': Generates a sum-of-sinusoid signal.
%          Default: TYPE = 'RBS'.
%    BAND: A 2 by 1 row vector that defines the frequency band for the
%          input's frequency contents.
%          For the 'RS', 'RBS' and 'SINE' cases BAND = [LFR,HFR], where
%          LFR and HFR are the lower and upper limits of the passband,
%          expressed in fractions of the Nyquist frequency (thus always
%          numbers between 0 and 1).
%          For the 'PRBS' case BAND = [2LOGP,M], where the periodicity
%          of the generated signal is 2^2LOGP-1, and M is such that the
%          signal is constant over intervals of length 1/M. 2LOGP = 0,
%          gives the maximum length PRBS, corresponding to 2LOGP = 18.
%          Default: BAND =[0 1].
%    LEVELS = [MI, MA]: A 2 by 1 row vector, defining the input levels.
%          For 'RBS', 'PRBS', and 'SINE', the levels are adjusted so
%          that the input signal always is between MI and MA.
%          For the 'RS' case, MI is the signal's mean value minus one
%          standard deviation and MA is the signal's mean plus one standard
%          deviation.
%          Default LEVELS = [-1 1].
%    In the 'SINE' case a 5th input argument NUMBERS can be used,
%    U = IDINPUT(N,TYPE,BAND,LEVELS,NUMBERS)
%    where NUMBERS = [no_of_sinusoids, no_of_trials], meaning that
%    no_of_sinusoids are equally spread over the indicated BAND, trying
%    no_of_trials different, random, relative phases, until the lowest
%    amplitude signal is found. Default: NUMBERS = [10,10];
%    

function idresamp
%MATLAB Tour Partial Function Help:  idn_con
%
% IDRESAMP Resamples data by decimation and interpolation.
%    ZD = IDRESAMP(Z,R)
% 
%    Z  : The output-input data matrix Z = [Y U]. Multi-variate
%         data are allowed
%    R  : The resampling factor. The new data record ZD will correspond
%         to a sampling interval of R times that of the original data.
%         R > 1 thus means decimation and R < 1 means interpolation.
%         Any positive number for R is allowed, but it will be replaced
%         by a rational approximation.
%    ZD : The resampled data. The columns of ZD correspond to those of Z.
% 
%    [ZD, ACT_R] = IDRESAMP(Z,R,ORDER,TOL) gives access to the following
%    options: ORDER determines the filter orders used at decimation
%    and interpolation (Default 8). TOL gives the tolerance of the
%    rational approximation (Default 0.1). ACT_R is the actually used
%    resampling factor.
%    

function covf
%MATLAB Tour Partial Function Help:  idn_con
%
% COVF  Computes the covariance function estimate for a data matrix.
%    R = COVF(Z,M)
% 
%    Z : An   N x nz data matrix, typically Z=[y u]
% 
%    M: The maximum delay - 1, for which the covariance function is estimated
%    R: The covariance function of Z, returned so that the entry
%    R((i+(j-1)*nz,k+1) is  the estimate of E Zi(t) * Zj(t+k)
%    The size of R is thus nz^2 x M.
%    For complex data z, RESHAPE(R(:,k+1),nz,nz) = E z(t)*z'(t+k)
%    (z' is complex conjugate, transpose)
% 
%    For nz<3, an FFT algorithm is used, memory size permitting.
%    For nz>2, straightforward summation is used (in COVF2)
% 
%    The memory trade-off is affected by
%    R = COVF(Z,M,maxsize)
%    

function cra
%MATLAB Tour Partial Function Help:  idn_con
%
% CRA    Performs correlation analysis to estimate impulse response.
%    IR = CRA(Z)
% 
%    Z: The data, entered with two columns Z = [y u]
%    IR: The estimated impulse response (IR(1) corresponds to g(0))
% 
%    [IR,R,CL] = CRA(Z,M,NA,PLOT) gives access to
%    M: The number of lags for which the functions are computed (def 20)
%    NA: The order of the whitening filter.(Def 10). With NA=0, no prewhite-
%        ning is performed. Then the covariance functions of the original
%        data are obtained.
%    PLOT: PLOT=0 gives no plots. PLOT=1 (Default) gives a plot of IR along
%        with a 99 % confidence region. PLOT=2 gives a plot of all R's
%    R: The covariance/correlation information
%       R(:,1) contains the lag indices
%       R(:,2) contains the covariance function of y (poss. prewhitened)
%       R(:,3) contains the covariance function of u (poss. prewhitened)
%       R(:,4) contains the correlation function between (poss prewhitened)
%         u and y (positive lags corresponds to an influence from u to y)
%       CL is the 99 % significance level for the impulse response
%       The plots can be redisplayed by CRA(R);

function etfe
%MATLAB Tour Partial Function Help:  idn_con
%
% ETFE   Computes the Empirical Transfer Function Estimate and Periodogram.
%    G = ETFE(Z)   or   G = ETFE(Z,M)
% 
%    Z contains the input-output data [y u] or a time series y. Only
%    single (or no) input systems can be handled. If an input is present
%    G is returned as the ETFE (the ratio of the output Fourier transform
%    to the input Fourier transform) for the data. For a time series G
%    is returned as the periodogram (the normed absolute square of the
%    Fourier transform) of the data. G is returned in the standard frequency
%    function format. 

function spa
%MATLAB Tour Partial Function Help:  idn_con
%
% SPA    Performs spectral analysis.
%    G = SPA(Z)  or  [G,NSP] = SPA(Z)
% 
%    Z : The output-input data Z=[y u], with y and u being column vectors.
%    For multi-variable systems Z=[y1 y2 .. u1 u2 ..]. For time-series Z=y.
%    If an input is present G is returned as the transfer function estimate,
%    and NSP (if specified) is the estimated noise spectrum.
%    Estimated standard deviations are also supplied. The functions are of
%    the standard frequency function format (

function ar
%MATLAB Tour Partial Function Help:  idn_con
%
% AR   Computes AR-models of signals using various approaches.
%    TH = AR(y,n)  or  TH = AR(y,n,approach)  or TH = AR(y,n,approach,win)
% 
%    TH: returned as the estimated parameters of the AR-model,

function armax
%MATLAB Tour Partial Function Help:  idn_con
%
% ARMAX    Computes the prediction error estimate of an ARMAX model.
%    TH = ARMAX(Z,NN)  or TH = ARMAX(Z,NN,'trace')
% 
%    TH: returned as  the estimated parameters of the ARMAX model
%    A(q) y(t) = B(q) u(t-nk) + C(q) e(t)
%    along with estimated covariances and structure information.
%    For the exact format of TH, 

function arx
%MATLAB Tour Partial Function Help:  idn_con
%
% ARX    Computes LS-estimates of ARX-models.
%    TH = ARX(Z,NN)
% 
%    TH: returned as the estimated parameters of the ARX model
%    A(q) y(t) = B(q) u(t-nk) + e(t)
%    along with estimated covariances and structure information.
%    For the exact structure of TH 

function bj
%MATLAB Tour Partial Function Help:  idn_con
%
% BJ   Computes the prediction error estimate of a Box-Jenkins model.
%    TH = BJ(Z,NN) or TH = BJ(Z,NN,'trace')
% 
%    TH: Returned as the estimated parameters of the Box-Jenkins model
%    y(t) = [B(q)/F(q)] u(t-nk) + [C(q)/D(q)] e(t)
%    along with estimated covariances and structure information. For
%    the exact format of TH, 

function canstart
%MATLAB Tour Partial Function Help:  idn_con
%
% CANSTART State-space model with initial parameter estimates.
%    THETA = CANSTART(Z,ORDERS,NU,DKX,AUXORD)
%    
%    THETA:  The resulting model, parametrized according to the orders
%            and with initial parameter estimates calculated
%            from data. No model covariances are given.
%    Z :     The output-input data [y u], with each input/output component
%            as a column vector.
%    ORDERS: The model order.  Optionally this argument can be given as a
%            vector with as many entries as there are output channels.
%            The model order is then the sum of these entries. Basically, 
%            ORDERS(k) gives the number of delays of output # k that are 
%            used by the model, and a canonical parametrization is built
%                up accordingly.
%    NU:     The number of inputs.
%    DKX: This is a vector defining the structure: DKX =[D,K,X]
%            D=1 indicates that a direct term from input to output will be 
%                estimated, while D=0 means that a delay from input to output
%            is postulated.
%        K=1 indicates that the K-matrix is estimated, while K=0 means that 
%                K will be fixed to zero. 
%            X=1 indicates that the initial state is estimated, X=0 that the
%            initial state is set to zero.
%            To define an arbitrary input delay structure NK, where NK(ku) is
%        the delay from input number ku to any of the outputs, let
%        DKX=[D,K,X,NK]. NK is thus a row vector of length=no of input
%        channels. When NK is specified, it overrides the value of D.
%            Default: DKX = [0, 1, 1]
%    AUXORD: The auxiliary order to be used by N4SID.
%    THETA is just an initial estimate of the system, and could be further
%          improved by TH = PEM(z,THETA);
% 
%    

function ivar
%MATLAB Tour Partial Function Help:  idn_con
%
% IVAR   Computes IV-estimates for the AR-part of a scalar time series.
%    TH = IVAR(Y,NA)
% 
%    TH: returned as the IV-estimate of the AR-part of a time series
%    model
%    A(q) y(t) =  v(t)
%    along with relevant structure information. (For the exact structure
%    of TH 

function iv4
%MATLAB Tour Partial Function Help:  idn_con
%
% IV4    Computes approximately optimal IV-estimates for ARX-models.
%    TH = IV4(Z,NN)
% 
%    TH: returned as the estimate of the ARX model
%    A(q) y(t) = B(q) u(t-nk) + v(t)
%    along with estimated covariances and structure information.
%    For the exact format of TH 

function n4sid
%MATLAB Tour Partial Function Help:  idn_con
%
% N4SID   Estimates a state-space model using a sub-space method.
%    TH=N4SID(Z) or [TH,AO]=N4SID(Z,ORDER,NY,AUXORD,DKX,MAXSIZE,TSAMP)
% 
%    TH: Returned as the estimated state-space model in the THETA format.
%        No model covariances are given.
%    Z : The output input data [y u], with y and u as column vectors
%        For multi-variable systems, Z=[y1 y2 ... yp u1 u2 ... un]
%    ORDER: The order of the model (Dimension of state vector). If entered
%        as a vector (e.g. 3:10) information about all these orders will be
%        given in a plot, Default; ORDER=1:10;
%        If ORDER is entered as 'best', the default order among 1:10 is
%        chosen.
%    NY: The number of outputs in the data matrix. Default NY =1.
%    AUXORD: An auxiliary order, that is used for the selection of state
%        variables. Default 1.2*ORDER+3. If AUXORD is entered as a row vector
%        the best value (min pred error) in this vector will be selected.
%    DKX: This is a vector defining the structure: DKX =[D,K,X]
%        D=1 indicates that a direct term from input to output will be
%                estimated, while D=0 means that a delay from input to output
%            is postulated.
%        K=1 indicates that the K-matrix is estimated, while K=0 means that
%                K will be fixed to zero.
%        X=1 indicates that the initial state is estimated, X=0 that the
%            initial state is set to zero.
%        To define an arbitrary input delay structure NK, where NK(ku) is
%        the delay from input number ku to any of the outputs, let
%        DKX=[D,K,X,NK]. NK is thus a row vector of length=no of input
%        channels. When NK is specified, it overrides the value of D.
%            Default: DKX = [0, 1, 1]
%        TRACE: Letting the last given argument be 'trace' gives info to screen
%        about fit and choice of AUXORD
%        MAXSIZE: 

function oe
%MATLAB Tour Partial Function Help:  idn_con
%
% OE     Computes the prediction error estimate of an output-error model.
%    TH = OE(Z,NN)  or TH = OE(Z,NN,'trace')
% 
%    TH: Returned as the estimated parameters of the output-error model
%    y(t) = [B(q)/F(q)] u(t-nk) + e(t)
%    along with estimated covariances and structure information.
%    For the exact format of TH, 

function pem
%MATLAB Tour Partial Function Help:  idn_con
%
% PEM   Computes the prediction error estimate of a general linear model.
%    TH = PEM(Z,THSTRUC) or TH = PEM(Z,THSTRUC,'trace')
% 
%    TH : returned as the estimated parameters of the model
%    along with estimated covariances and structure information.
%    For the exact format of TH 

function arx2th
%MATLAB Tour Partial Function Help:  idn_con
%
% ARX2TH Constructs the THETA-format for an ARX model.
%    TH=ARX2TH(A,B,ny,nu)
% 
%    A,B: The given matrix polynomials for a (possibly) multivariable
%    ARX-model
%    y(t) + A1 y(t-1) + .. + An y(t-n) =
%    = B0 u(t) + ..+ B1 u(t-1) + .. Bm u(t-m)
%    A = [I A1 A2 .. An],  B=[B0 B1 .. Bm]
%    ny, nu : The number of outputs and inputs, respectively
% 
%    TH is returned as a model structure (in the THETA-format)
%    where free parameters are consistent with the structure of A
%    and B, i.e. leading zeros in the rows of B are regarded as fixed
%    delays, and trailing zeros in the rows of A and B are regarded as a
%    definition of lower order polynomials. These zeros will thus be
%    regarded as fixed while all other parameters are free. The nominal
%    values of these free parameters are set equal to the values in A and B.
%    With th = ARX2TH(A,B,ny,nu,LAMBDA,Tsamp) also the innovations covarian-
%    ce matrix LAMBDA and the sampling interval Tsamp can be specified.
% 
%    

function canform
%MATLAB Tour Partial Function Help:  idn_con
%
% CANFORM Constructs canonical form model structures.
%    MS = CANFORM(ORDERS,NU,DKX)
% 
%    MS:     The resulting model structure, to be used e.g. in MS2TH
%    ORDERS: Defines the model order and structure. This is a
%            vector with as many entries as there are output channels.
%            The model order is then the sum of these entries. Basically, 
%            ORDERS(k) gives the number of delays of output # k that are 
%            used by the model, and a canonical parametrization is built
%                up accordingly. (These are the pseudo-observability indices, 
%            defining the structure. See e.g. Ljung(1987), Appendix 4.A.)
%    NU:     The number of inputs
%    DKX:    Determines whether to estimate the K (Kalman gain/Noise model),
%            D (Direct term from input to output) and X0 (intial state) 
%            elements in the state-space model. Enter as DKX = [D, K, X0],
%            where entry '0' means not to estimate, but fix to 0, while
%            '1' means that the corresponding matrix is estimated.
%            To define an arbitrary input delay structure NK, where NK(ku) is
%            the delay from input number ku to any of the outputs, let
%            DKX=[D,K,X,NK]. NK is thus a row vector of length=no of input
%            channels. When NK is specified, it overrides the value of D.
%            Default: DKX = [0, 1, 0]
% 
%    It may be difficult to find reasonable initial parameter estimates.
%    In that case, use CANSTART.
% 
%    

function mf2th
%MATLAB Tour Partial Function Help:  idn_con
%
% MF2TH  Packages user defined model structures into the THETA model format.
%    TH = MF2TH(MODEL,CD,PARVAL,AUX,LAMBDA,T)
% 
%    TH: The resulting model matrix
% 
%    MODEL: The model structure specified as the name of a user-written
%    m-file, which should have the format
% 
%            [a,b,c,d,k,x0]=username(parameters,T,AUX)
% 
%    Then MODEL='username'. 

function modstruc
%MATLAB Tour Partial Function Help:  idn_con
%
% MODSTRUC  Constructs model structures to be used in MS2TH.
%    MS = MODSTRUC(A,B,C,D,K,X0)
% 
%    MS = The resulting model structure.
%    A,B,C,D,K,X0 are the matrices of the state-space model
% 
%    xnew = A x(t) + B u(t) + K e(t)
%    y(t) = C x(t) + D u(t) + e(t)
% 
%    where xnew is x(t+T) or dx(t)/dt. X0 is the initial state.
% 
%    The entries of these matrices are numerical values for the parameters
%    that are fixed, while a parameter to be estimated (a free parameter) is
%    entered as NaN in the corresponding position.
%    Example: A=[0 1;NaN NaN].
%    The default value of X0 is zeros.
%    

function ms2th
%MATLAB Tour Partial Function Help:  idn_con
%
% MS2TH  Packages standard state-space parameterizations into the THETA format.
%    THETA = MS2TH(MS,CD,PARVAL,LAMBDA,T)
% 
%    THETA: The resulting matrix in the THETA format (See help theta)
% 
%    MS: The model structure. Specifies which state-space matrix coeff-
%    icients that are free and which are fixed (Generated by (

function fixpar
%MATLAB Tour Partial Function Help:  idn_con
%
% FIXPAR   Fixes parameters in state-space and ARX model structures.
%    TH = FIXPAR(TH_OLD,MATRIX,ELEMENTS,PARAMETERVALUES)
% 
%    TH : The new theta-matrix
%    TH_OLD: The old theta-matrix
%    MATRIX: What matrix to manipulate (one of 'A','B','C','D','K' or 'X0')
%    ELEMENTS: Which elements to manipulate; an n by 2 matrix, where   each
%    row contains the row- and column numbers of the elements in question.
%    If this argument is omitted, all elements in the matrix will be fixed.
%    PARAMETERVALUES: The values of the new, fixed parameters;a vector with
%    n entries. If this argument is omitted, the parameters will be fixed to
%    the values of the current estimates in TH_OLD.
%    If MATRIX is given the value 'A1', 'A2', etc or 'B0', 'B1' etc
%    the manipulations will be obtained in the corresponding matrix
%    in an ARX-structure, provided TH_OLD is defined as such.
% 
%    Example: th1 = FIXPAR(th,'A',[3,1;2,2;1,3])
% 
%    Note: FIXPAR works only on standard model structures originally
%    defined by MS2TH, ARX2TH or ARX; if TH_OLD is based on a user-
%    defined structure, you could obtain the same result with THINIT and by
%    using the 3rd argument in PEM.
%    

function sett
%MATLAB Tour Partial Function Help:  idn_con
%
% SETT   Sets the sampling interval in TH-structures and frequency functions.
%    THN = sett(TH,T)  or GN = sett(G,T)
% 
%    TH:  The original model in THETA-format
%    T:   The sampling interval
%    THN: The new model in THETA-format, with sampling interval T
%    or
%    G:   The original frequency function
%    GN:  The frequency function with frequencies scaled according to
%         the desired sampling interval
%    For frequency functions SETT works only for functions generated by
%    (

function thinit
%MATLAB Tour Partial Function Help:  idn_con
%
% THINIT Initial parameter values for iterative estimation.
%    TH = THINIT(TH0) or TH = THINIT(TH0,R,PAR,SP)
% 
%    TH0:Original theta corresponding to state-space model (

function unfixpar
%MATLAB Tour Partial Function Help:  idn_con
%
% UNFIXPAR Unfixes parameters in state-space and ARX model structures.
%    TH = UNFIXPAR(TH_OLD,MATRIX,ELEMENTS)
% 
%    TH : The new theta-matrix
%    TH_OLD: The old theta-matrix
%    MATRIX: What matrix to manipulate
%            (one of 'A','B','C','D','K' or 'X0')
%    ELEMENTS: Which elements to manipulate; an n by 2 matrix, where
%            each row contains the row- and column numbers of the elements
%            in question. If this argument is omitted, all elements in the
%            matrix will be unfixed.
% 
%    Example: th1 = unfixpar(th,'A',[3,1;2,2;1,3]);
% 
%    If MATRIX is given the value 'A1', 'A2', etc or 'B0', 'B1' etc
%    the manipulations will be obtained in the corresponding matrix
%    in an ARX-structure, provided TH_OLD is defined as such.
% 
%    Note: UNFIXPAR works only on standard model structures
%    originally defined by MS2TH, ARX2TH or ARX; if TH_OLD is based on a
%    user-defined structure (by MF2TH), you must unfix it yourself
%    

function idmodred
%MATLAB Tour Partial Function Help:  idn_con
%
% IDMODRED  Reduces the order of models.
%    THRED = IDMODRED(TH,ORDER,OE)
% 
%    TH: Original model in THETA format.
%    ORDER: Desired order of reduced model.
%       If ORDER=[] (default), a plot is shown, and you are
%       prompted to select the order.
%    OE: If OE='oe', an output error model is produced,
%        otherwise also the noise model is reduced.
%    THRED: The reduced order model in THETA format.
% 
%    The routine is based on (d)balreal and (d)modred in the
%    Control Systems Toolbox.
%    

function th2arx
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2ARX converts a THETA-format model to an ARX-model.
%    [A,B]=TH2ARX(TH)
% 
%    TH: The model structure defined in the THETA-format (

function th2ff
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2FF  Computes a model's frequency function,along with its standard deviation
%    G = TH2FF(TH)  or  [G,NSP] = TH2FF(TH)
% 
%    TH: A matrix defining a model, as described (

function th2par
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2PAR converts the theta-format to parameters and covariance matrix.
%    [PAR,P,LAM] = TH2PAR(TH)
% 
%    TH: The model defined in the THETA-format (

function th2poly
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2POLY computes the polynomials associated with a given model.
%    [A,B,C,D,F,LAM,T]=TH2POLY(TH)
% 
%    TH is the model with format described by (

function th2ss
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2SS  Transforms a model in THETA-format to state-space.
%    [A,B,C,D,K,X0]=TH2SS(TH)
% 
%    TH: The model, defined in the THETA format (

function th2tf
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2TF  Transforms from the THETA-format to transfer functions.
%    [NUM,DEN] = TH2TF(TH,IU)
% 
%    TH: The model, defined in the THETA-format (

function th2zp
%MATLAB Tour Partial Function Help:  idn_con
%
% TH2ZP  Computes zeros, poles, static gains and their standard deviations.
%    [ZEPO,K] = TH2ZP(TH)
% 
%    For a model defined by TH (in the theta format. 

function thc2thd
%MATLAB Tour Partial Function Help:  idn_con
%
% THC2THD  Converts a continuous time model to discrete time.
%    THD = THC2THD(THC,T)
% 
%    THC: The continuous time model, specified in THETA format
%            (

function thd2thc
%MATLAB Tour Partial Function Help:  idn_con
%
% THD2THC  converts a model to continuous-time form.
%    THC = THD2THC(TH)
% 
%    TH: A discrete time model defined in the theta format, 

function bodeplot
%MATLAB Tour Partial Function Help:  idn_con
%
% BODEPLOT Plots the Bode diagram of a transfer function or spectrum.
%    BODEPLOT(G)  or  BODEPLOT(G,SD)
% 
%    G is entered as the transfer function(s) or spectrum (spectra)
%    of the standard frequency function format, produced by TH2FF,
%    SPA or ETFE. 

function ffplot
%MATLAB Tour Partial Function Help:  idn_con
%
% BODEPLOT Plots the Bode diagram of a transfer function or spectrum.
%    BODEPLOT(G)  or  BODEPLOT(G,SD)
% 
%    G is entered as the transfer function(s) or spectrum (spectra)
%    of the standard frequency function format, produced by TH2FF,
%    SPA or ETFE. 

function idplot
%MATLAB Tour Partial Function Help:  idn_con
%
% IDPLOT Plots input - output data.
%    IDPLOT(Z)   or   IDPLOT(Z,INT)
% 
%    Z is the input - output data [y u]. This is plotted with output over
%    input. The data points specified in the row vector INT are selected.
%    The default value is all data.
%    If the sampling interval is T, correct time axes are obtained by
% 
%    IDPLOT(Z,INT,T)
% 
%    If the data is multi-output, appropriate plots are obtained by
% 
%    IDPLOT(Z,INT,T,NY)
% 
%    where NY is the number of outputs, i.e the ny first columns of Z.
% 
%    It is assumed that the input is piecewise constant between sampling
%    instants, and it is plotted accordingly. If linear interpolation
%    between input data points is preferred, use
%    
%    IDPLOT(Z,INT,T,NY,'LI')

function nyqplot
%MATLAB Tour Partial Function Help:  idn_con
%
% NYQPLOT  plots the Nyquist diagram of a frequency function.
%    NYQPLOT(G)  or  NYQPLOT(G,SD)
% 
%    G is entered as the transfer function(s) of the standard frequency
%    function format, produced by TH2FF, SPA or ETFE.
%    

function present
%MATLAB Tour Partial Function Help:  idn_con
%
% PRESENT  presents a parametric model on the screen.
%    PRESENT(TH)
% 
%    This function displays the model TH together estimated standard
%    deviations, innovations variance, loss function and Akaike's Final
%    Prediction Error criterion (FPE).

function zpplot
%MATLAB Tour Partial Function Help:  idn_con
%
% ZPPLOT Plots zeros and poles.
%    ZPPLOT(ZEPO)   or   ZPPLOT(ZEPO,SD)  or  ZPPLOT(ZEPO,MODE)
%                   or   ZPPLOT(ZEPO,SD,MODE,AXIS)
% 
%    The zeros and poles, specified by ZEPO (See TH2ZP, or ZPFORM 
%    for the format) are plotted, with 'o' denoting zeros and 'x' poles.
%    Poles and zeros associated with the same input, but different models
%    are always plotted in the same diagram, and 'ENTER' advances the plot 
%    from one model to the next (if any).
% 
%    When ZEPO contains information about several different inputs there
%    are some options: 
%    MODE='sub' (The default value) splits the screen into several plots.
%    MODE='same' gives all plots in the same diagram. Use 'ENTER' to advance
%    MODE='sep' erases the previous plot before the next input is treated.
%    AXIS=[x1 x2 y1 y2] fixes the axes scaling.
%    AXIS=m is the same as AXIS=[-m m -m m]. Default is autoscaling
%    If SD>0, confidence regions around the poles and zeros are plotted.
%    The region corresponding to SD standard deviations is marked.
%    SD=0 is default.
%    For multi-output models, each output is handled separately.
%    

function getmfth
%MATLAB Tour Partial Function Help:  idn_con
%
% GETMFTH Gets the name of the .m-file that defines the model structure
% 
%    MFNAME = getmfth(TH)
% 
%    TH: The model structure defined in the THETA-format (See help theta)
%    MFNAME: The name of the m-file that defines the structure

function getncap
%MATLAB Tour Partial Function Help:  idn_con
%
% GETNCAP Gets the number of data points and the number of parameters for a model.
% 
%    [Ncap,D]=getncap(TH);
% 
%    TH: The model, defined in the THETA-format (See help theta)
%    Ncap: The number of data points (samples) that were used to estimate TH
%       (If the model is not estimated, Ncap is returned as [])
%    D: The number of estimated parameters in the model structure

function getff
%MATLAB Tour Partial Function Help:  idn_con
%
% GETFF  Selects the frequency function (for own plotting).
%    [W,AMP,PHAS] = GETFF(G,NU,NY)
% 
%    W: The frequency scale in radians/second
%    AMP: The amplitude function
%    PHAS: The phase function (in degrees)
%    G: The frequency function in the FREQFUNC format. 

function gett
%MATLAB Tour Partial Function Help:  idn_con
%
% GETT   Gets the sampling interval for a model.
%    T = GETT(TH)
% 
%    T: The sampling interval
%    TH: The model, defined in the THETA-format (

function getzp
%MATLAB Tour Partial Function Help:  idn_con
%
% GETZP  Extracts the zeros and the poles from the ZEPO-format created by TH2ZP.%        [Z,P] = GETZP(ZEPO,KU,KY)
% 
%    Z : The zeros
%    P : The poles
%    ZEPO: The matrix of zeros and poles, resulting from th2zp
%    KU : The input number (default 1). Noise source #ju is represented as
%         input number -ju.
% 
%    KY : The output number (default 1).
% 
%    If several entries in ZEPO correspond to the same input-output
%    relation, then Z and P will contain one column for each model.
%    Z and P will be stripped from spurious 'inf':s and zeros as far
%    as possible.
% 
%    [Z,P,Zsd,Psd] = GETZP(ZEPO,KU,KY) gives access to the standard
%    deviations of the zeros and poles, respectively.

function compare
%MATLAB Tour Partial Function Help:  idn_con
%
% COMPARE Compares the simulated/predicted output with the measured output.
%    YH = COMPARE(Z,TH,M)
% 
%    Z : The output - input data for which the comparison is made (the
%        validation data set.
%    TH: The model in the THETA format (

function resid
%MATLAB Tour Partial Function Help:  idn_con
%
% RESID  Computes and tests the residuals associated with a model.
%    E = RESID(Z,TH)
% 
%    Z : The output-input data Z=[y u], with y and u being column vectors.
%    For multi-variable systems Z=[y1 y2 .. yp u1 u2 ... un]. 
%    For time-series Z=y only.
%    TH: The model to be evaluated on the given data set. (For the theta 
%    format, 

function idsimsd
%MATLAB Tour Partial Function Help:  idn_con
%
% IDSIMSD Illustrates the uncertainty in simulated model responses.
%    IDSIMSD(U,TH)
% 
%    U is a column vector (matrix) containing the input(s).
%    TH is a model given in the THETA format (

function arxstruc
%MATLAB Tour Partial Function Help:  idn_con
%
% ARXSTRUC Computes loss functions for families of ARX-models.
%    V = ARXSTRUC(Z,ZV,NN)
% 
%    V: The first row of V is returned as the loss functions of the
%    structures defined by the rows of NN. The remaining rows are
%    returned as NN'. The last column of V contains the number of
%    data points in Z.
% 
%    Z : the output-input data Z=[y u], with y and u as column vectors.
%    Only Single-Output data are handled by this routine!
%    For a time series Z=y only.
%    ZV: the input-output data on which the validation is performed.
%    (could equal Z). The number of rows in ZV need not equal those in Z.
% 
%    NN: Each row of NN is of the format [na nb nk], the orders and delays
%    of the corresponding ARX model.(

function ivstruc
%MATLAB Tour Partial Function Help:  idn_con
%
% IVSTRUC Computes the output error fit for families of single-output ARX-models.
%    V = IVSTRUC(ZE,ZV,NN)
% 
%    V: The first row of V is returned as the output error fit for
%    models of the structures, defined by the rows of NN.
%    These models are computed by the IV-method. The next rows
%    of V are returned as NN'. The last row of V contains the logarithms
%    of the conditioning numbers of the IV-matrix for the structures in
%    question. The last column of V contains the number of data points in Z
% 
%    ZE : the output-input data Z=[y u], with y and u as column vectors.This
%    data is used for estimation. For multi-input systems u=[u1 u2 ... un]
%    ZV : output-input data used to evaluate the models (could equal ZE).
%    NN: Each row of NN is of the format [na nb nk], the orders and
%    delays associated with the corresponding model. (

function selstruc
%MATLAB Tour Partial Function Help:  idn_con
%
% SELSTRUC Selects model structures according to various criteria.
% 
%    nn = selstruc(V,c)    or   [nn,Vm] = selstruc(V,c)
% 
%    V: is a matrix containing information about different structures,
%    typically obtained as the output of ARXSTRUC or IVSTRUC.
% 
%    c: selects the criterion: c='PLOT' gives plots of the loss function
%    and (if applicable) the conditioning number from IVSTRUC as func-
%    tions of the number of estimated parameters. The user then selects the
%    number of parameters.
%    Automatic choices of structures are obtained by c='AIC', which gives
%    Akaike's information theoretic criterion, while c='MDL' gives
%    Rissanen's minimum description length criterion. If c is given a
%    numeric value the structure is selected by minimization of
%    (1 + c*d/N)*Vd, where d is the number of estimated parameters,
%    Vd is the loss function of the corresponding model, and N is the
%    number of data. If c is omitted, PLOT is chosen.
% 
%    nn: is returned as the chosen structure. The format is compatible
%    with the input format for ARX and IV4.
%    Vm: the first row of Vm contains the logarithms of the modified
%    criteria of fit. The remaining rows of Vm coincide with V.

function struc
%MATLAB Tour Partial Function Help:  idn_con
%
% STRUC  generates typical structure matrices for ARXSTRUC and IVSTRUC.
%    NN = STRUC(NA,NB,NK)
% 
%    NA, NB and NK are vectors containing the orders na, nb and delays nk
%    to be tested. See HELP ARX for an explanation of na, nb and nk.
%    NN is returned as a matrix containing all combinations of these
%    orders and delays. The function is intended for single input systems
%    only.
% 
%    

